  program main

    use vtype_module
    use ni3_module
    use fi_module
    use netcdf

    implicit none

    character(extstr) :: CtlFN = "addcnt.conf"
    integer           :: FileUnit

    integer         :: NWaveNum
    integer         :: NMolNum
    integer         :: NLev
    integer         :: NTmp

    real(8), allocatable :: w_WaveNum   (:)
    integer, allocatable :: m_MolNum    (:)
    real(8), allocatable :: r_Press     (:)
    real(8), allocatable :: r_Temp      (:)
    real(8), allocatable :: rm_VMR      (:,:)
    real(8), allocatable :: rm_AbsCoef1 (:,:)
    real(8), allocatable :: rm_AbsCoef2 (:,:)

    real(8)              :: WaveNum
    real(8)              :: Press
    real(8)              :: Temp
    real(8)              :: AbsCoef

    character(256)            :: DirIn
    character(256)            :: FileIn
    integer                   :: FUIn
    integer                   :: NLine

    character(extstr*10)      :: NcFNIn1
    character(extstr*10)      :: NcFNIn2
    character(extstr*10)      :: NcFNOut
    character(256)            :: VarName

    character(256)            :: MolName

    integer                   :: NcIDIn1
    integer                   :: NcIDIn2
    integer                   :: NcIDOut
    character(256)            :: Title
    character(256)            :: Com
    character(256)            :: Name
    character(256)            :: StdName
    character(256)            :: LongName
    character(256)            :: Units

    integer                     :: VarIDAbsCoef
    integer                     :: St2(2)
    integer                     :: Co2(2)
    integer                     :: St3(3)
    integer                     :: Co3(3)

    integer                     :: NDims
    character(256), allocatable :: a_DimNames(:)
    real(8)                     :: MissingValue

    integer                     :: iStatus

    character(256)              :: Line
    integer                     :: iostat

    integer                     :: k
    integer                     :: m
    integer                     :: iWaveNum
    integer                     :: iLoop

    real(8)                     :: WaveNumS
    real(8)                     :: WaveNumE

    real(8)                     :: WaveNumTmp


    namelist /file_nml/ &
      & NcFNIn1, NcFNIn2, NcFNOut


    ! Read a namelist file

    call fi_open( CtlFN, "read", FileUnit )
    !
    rewind( FileUnit )
    read( FileUnit, nml = file_nml, iostat = iostat )
    if ( iostat > 0 ) then
      stop 'Namelist in file_nml is something wrong.'
    end if
    write( 6, nml = file_nml )
    !
    close( FileUnit )



    !
    ! Prepare for input NetCDF files
    !
    write( 6, * ) 'Input file #1 : ', trim( NcFNIn1 )
    call ni3_open( NcFNIn1, "read", NcIDIn1 )
    write( 6, * ) 'Input file #2 : ', trim( NcFNIn2 )
    call ni3_open( NcFNIn2, "read", NcIDIn2 )
    !
    call ni3_inq_dimlen( NcIDIn1, "MolNum" , NMolNum  )
    call ni3_inq_dimlen( NcIDIn1, "Press"  , NLev     )
    call ni3_inq_dimlen( NcIDIn1, "WaveNum", NWaveNum )
    !
    call ni3_inq_dimlen( NcIDIn2, "MolNum" , NTmp )
    if ( NTmp /= NMolNum ) then
      write( 6, * ) 'Dimension length does not match: ', NMolNum, NTmp
      stop
    end if
    call ni3_inq_dimlen( NcIDIn2, "Press"  , NTmp )
    if ( NTmp /= NLev ) then
      write( 6, * ) 'Dimension length does not match: ', NLev, NTmp
      stop
    end if
    call ni3_inq_dimlen( NcIDIn2, "WaveNum", NTmp )
    if ( NTmp /= NWaveNum ) then
      write( 6, * ) 'Dimension length does not match: ', NWaveNum, NTmp
      stop
    end if
    !
    allocate( m_MolNum     ( NMolNum ) )
    allocate( r_Press      ( NLev ) )
    allocate( r_Temp       ( NLev ) )
    allocate( rm_VMR       ( NLev, NMolNum ) )
!!$    allocate( rm_AbsCoef   ( NMolNum ) )
    call ni3_get_var( NcIDIn1, "MolNum", m_MolNum )
    call ni3_get_var( NcIDIn1, "Press" , r_Press  )
    call ni3_get_var( NcIDIn1, "Temp"  , r_Temp   )
    call ni3_get_var( NcIDIn1, "VMR"   , rm_VMR   )

    !
    ! Prepare for output to a NetCDF file
    !
    write( 6, * ) 'Output file : ', trim( NcFNOut )
    call ni3_open( NcFNOut, "new", NcIDOut )
    !
    call ni3_cp_atts( NcIDIn1, NcIDOut, "_global_" )
    !
    Name     = "MolNum"
    call ni3_set_dim( NcIDOut, Name, NI3_INT, m_MolNum )
    call ni3_cp_atts( NcIDIn1, NcIDOut, Name )
    Name     = "Press"
    call ni3_set_dim( NcIDOut, Name, NI3_DOUBLE, r_Press )
    call ni3_cp_atts( NcIDIn1, NcIDOut, Name )
    Name     = "WaveNum"
    call ni3_def_dim( NcIDOut, Name, NI3_DOUBLE, NI3_UNLIMITED )
    call ni3_cp_atts( NcIDIn1, NcIDOut, Name )

    NDims = 1
    allocate( a_DimNames( NDims ) )
    a_DimNames( 1 ) = "Press"
    !
    Name         = "Temp"
    call ni3_def_var( NcIDOut, Name, NI3_DOUBLE, NDims, a_DimNames )
    call ni3_cp_atts( NcIDIn1, NcIDOut, Name )
    !
    deallocate( a_DimNames )

    NDims = 2
    allocate( a_DimNames( NDims ) )
    a_DimNames( 1 ) = "Press"
    a_DimNames( 2 ) = "MolNum"
    !
    Name         = "VMR"
    call ni3_def_var( NcIDOut, Name, NI3_DOUBLE, NDims, a_DimNames )
    call ni3_cp_atts( NcIDIn1, NcIDOut, Name )
    !
    deallocate( a_DimNames )

    NDims = 3
    allocate( a_DimNames( NDims ) )
    a_DimNames( 1 ) = "Press"
    a_DimNames( 2 ) = "MolNum"
    a_DimNames( 3 ) = "WaveNum"
    !
    Name         = "AbsCoef"
    call ni3_def_var( NcIDOut, Name, NI3_DOUBLE, NDims, a_DimNames )
    call ni3_cp_atts( NcIDIn1, NcIDOut, Name )
    !
    deallocate( a_DimNames )


    call ni3_put_var( NcIDOut, "Temp", r_Temp )
    call ni3_put_var( NcIDOut, "VMR" , rm_VMR )

    call ni3_inq_var( NcIDOut, "AbsCoef", VarIDAbsCoef )


    allocate( rm_AbsCoef1 (NLev, NMolNum) )
    allocate( rm_AbsCoef2 (NLev, NMolNum) )

    do iWaveNum = 1, NWaveNum

      call ni3_get_varss( NcIDIn1, "WaveNum", iWaveNum, WaveNum )
      call ni3_get_varss( NcIDIn2, "WaveNum", iWaveNum, WaveNumTmp )
      if ( abs( WaveNum - WaveNumTmp ) > 1.0d-3 ) then
        write( 6, * ) iWaveNum, WaveNum, WaveNumTmp
        stop
      end if
      !
      call ni3_get_varss( NcIDIn1, "AbsCoef", iWaveNum, rm_AbsCoef1 )
      call ni3_get_varss( NcIDIn2, "AbsCoef", iWaveNum, rm_AbsCoef2 )

      call ni3_put_varss( NcIDOut, "WaveNum", iWaveNum, WaveNum )
      call ni3_put_varss( NcIDOut, "AbsCoef", iWaveNum, rm_AbsCoef1+rm_AbsCoef2 )

    end do

    call ni3_close( NcIDIn1)
    call ni3_close( NcIDIn2 )
    call ni3_close( NcIDOut )

    write( 6, * ) 'Finish'

  end program main
